@@ -8,20 +8,18 @@ be thin.  Business rules must be decoupled from the web framework.
 """
 
 from datetime import datetime
-from typing import Any, Optional
+from typing import Optional
 
 from bag.reify import reify
-from kerno.action import Action
 from kerno.state import MalbonaRezulto, Rezulto
 from pyramid_mailer import get_mailer
 from pyramid_mailer.message import Message
 
 from pluserable import const
-from pluserable.data.typing import TUser
-from pluserable.events import EventLogin
+from pluserable.data.typing import ActivationRezulto, TUser, UserRezulto
 from pluserable.exceptions import AuthenticationFailure
-from pluserable.data.repository import AbstractRepo
 from pluserable.strings import get_strings, UIStringsBase
+from pluserable.web.pyramid.typing import UserlessPeto
 
 
 def get_activation_link(request, user_id: int, code: str) -> str:
@@ -33,12 +31,9 @@ def get_activation_link(request, user_id: int, code: str) -> str:
     So we take advantage of a ``scheme_domain_port`` configuration
     setting if provided.
     """
-    scheme_domain_port: str = request.registry.settings.get(
-        "scheme_domain_port", ""
-    )
+    scheme_domain_port: str = request.registry.settings.get("scheme_domain_port", "")
     return (
-        scheme_domain_port
-        + request.route_path("activate", user_id=user_id, code=code)
+        scheme_domain_port + request.route_path("activate", user_id=user_id, code=code)
         if scheme_domain_port
         else request.route_url("activate", user_id=user_id, code=code)
     )
@@ -58,9 +53,7 @@ def create_activation(request, user):  # TODO Lose *request* argument
         repo.flush()
 
     # The application can configure a function that sends the email message.
-    send_activation_email = request.kerno.utilities[
-        "pluserable.send_activation_email"
-    ]
+    send_activation_email = request.kerno.utilities["pluserable.send_activation_email"]
     send_activation_email(request, user)
 
 
@@ -76,9 +69,7 @@ def send_activation_email(request, user):
         recipients=[user.email],
         body=strings.activation_email_plain.replace(
             "ACTIVATION_LINK",
-            get_activation_link(
-                request, user_id=user.id, code=user.activation.code
-            ),
+            get_activation_link(request, user_id=user.id, code=user.activation.code),
         ),
     )
     mailer = get_mailer(request)
@@ -94,12 +85,9 @@ def get_reset_link(request, code: str) -> str:
     So we take advantage of a ``scheme_domain_port`` configuration
     setting if provided.
     """
-    scheme_domain_port: str = request.registry.settings.get(
-        "scheme_domain_port", ""
-    )
+    scheme_domain_port: str = request.registry.settings.get("scheme_domain_port", "")
     return (
-        scheme_domain_port
-        + request.route_path("reset_password", code=code)
+        scheme_domain_port + request.route_path("reset_password", code=code)
         if scheme_domain_port
         else request.route_url("reset_password", code=code)
     )
@@ -129,45 +117,52 @@ def send_reset_password_email(request, user):
     mailer.send(message)
 
 
-class PluserableAction(Action):
+class UserlessAction:
     """Base class for our actions."""
 
-    repo: AbstractRepo  # let mypy know about our repo interface
+    def __init__(self, upeto: UserlessPeto):  # noqa
+        self.upeto = upeto
 
     @reify
     def _strings(self) -> UIStringsBase:
-        return get_strings(self.kerno)
+        return get_strings(self.upeto.kerno)
 
 
-def require_activation_setting_value(kerno) -> bool:
-    """Return the value of a certain setting."""
-    return kerno.pluserable_settings.bool("require_activation", default=True)
-
-
-class CheckCredentials(PluserableAction):
+class CheckCredentials(UserlessAction):
     """Business rules decoupled from the web framework and from persistence."""
 
     @property
     def _require_activation(self):
-        return require_activation_setting_value(self.kerno)
+        return self.upeto.kerno.pluserable_settings["require_activation"]
 
     def q_user(self, handle: str) -> Optional[TUser]:
         """Fetch user. ``handle`` can be a username or an email."""
         if "@" in handle:
-            return self.repo.get_user_by_email(handle)
+            return self.upeto.repo.get_user_by_email(handle)
         else:
-            return self.repo.get_user_by_username(handle)
+            return self.upeto.repo.get_user_by_username(handle)
 
-    def __call__(self, handle: str, password: str) -> Rezulto:
-        """Get user object if credentials are valid, else raise."""
-        rezulto: Any = Rezulto()
-        rezulto.user = self.q_user(handle)  # IO
-        self._check_credentials(rezulto.user, handle, password)  # might raise
-        assert rezulto.user
-        rezulto.user.last_login_date = datetime.utcnow()
-        self.kerno.events.broadcast(
-            EventLogin(peto=self.peto, rezulto=rezulto)
+    def __call__(self, handle: str, password: str, ip: str) -> UserRezulto:
+        """Get user object if credentials are valid; also prevent brute force."""
+        # First check redis for this IP to stop brute force attacks
+        bruteforce_aid = self.upeto.kerno.utilities["brute force class"](
+            kerno=self.upeto.kerno, ip=ip
         )
+        seconds, error_msg = bruteforce_aid.is_login_blocked()
+        if error_msg:
+            raise AuthenticationFailure(error_msg)
+
+        # Brute force check passes, so now check the credentials.
+        user = self.q_user(handle)  # IO
+        try:
+            self._check_credentials(user, handle, password)
+        except AuthenticationFailure as exc:
+            # If the credentials are wrong, store the IP in redis
+            exc.seconds = bruteforce_aid.store_login_failure()
+            raise exc
+        assert user
+        user.last_login_date = datetime.utcnow()
+        rezulto: UserRezulto = UserRezulto(user=user)
         return rezulto
 
     def _check_credentials(
@@ -186,10 +181,10 @@ class CheckCredentials(PluserableAction):
         return user
 
 
-class ActivateUser(PluserableAction):  # noqa
-    def __call__(self, code: str, user_id: int) -> Rezulto:
+class ActivateUser(UserlessAction):  # noqa
+    def __call__(self, code: str, user_id: int) -> ActivationRezulto:
         """Find code, ensure belongs to user, delete activation instance."""
-        activation = self.repo.get_activation_by_code(code)
+        activation = self.upeto.repo.get_activation_by_code(code)
         if not activation:
             raise MalbonaRezulto(
                 status_int=404,
@@ -197,7 +192,7 @@ class ActivateUser(PluserableAction):  # noqa
                 plain=self._strings.activation_code_not_found,
             )
 
-        user = self.repo.get_user_by_id(user_id)
+        user = self.upeto.repo.get_user_by_id(user_id)
         if not user:
             raise MalbonaRezulto(
                 status_int=404,
@@ -212,8 +207,8 @@ class ActivateUser(PluserableAction):  # noqa
                 plain=self._strings.activation_code_not_match,
             )
 
-        self.repo.delete_activation(user, activation)
-        ret = Rezulto()  # type: Any
+        self.upeto.repo.delete_activation(user, activation)
+        ret = ActivationRezulto()
         ret.user = user
         ret.activation = activation
 
