@@ -5,7 +5,7 @@ from typing import Any, Dict, Generic, Optional
 
 from bag.reify import reify
 from bag.text import random_string
-from kerno.repository.sqlalchemy import BaseSQLAlchemyRepository, Query
+from kerno.repository.sqlalchemy import Query
 from sqlalchemy import func
 
 from pluserable import const
@@ -14,10 +14,7 @@ from pluserable.data.typing import TActivation, TGroup, TUser
 
 
 class Repository(AbstractRepo, Generic[TActivation, TGroup]):
-    """A repository that uses SQLAlchemy for storage.
-
-    In the future other strategies can be developed (e. g. ZODB).
-    """
+    """A repository that uses SQLAlchemy for storage."""
 
     @reify
     def User(self) -> TUser:  # noqa
@@ -31,14 +28,10 @@ class Repository(AbstractRepo, Generic[TActivation, TGroup]):
     def Group(self) -> TGroup:  # noqa
         return self.kerno.utilities[const.GROUP_CLASS]
 
-    def get_user_by_activation(
-        self, activation: TActivation
-    ) -> Optional[TUser]:
+    def get_user_by_activation(self, activation: TActivation) -> Optional[TUser]:
         """Return the user with ``activation``, or None."""
         return (
-            self.sas.query(self.User)
-            .filter(self.User.activation == activation)
-            .first()
+            self.sas.query(self.User).filter(self.User.activation == activation).first()
         )
 
     def get_user_by_id(self, id: int) -> Optional[TUser]:
@@ -90,9 +83,7 @@ class Repository(AbstractRepo, Generic[TActivation, TGroup]):
         user.activation = None
         self.delete(activation)
 
-    def delete_expired_activations(
-        self, now: Optional[datetime] = None
-    ) -> int:
+    def delete_expired_activations(self, now: Optional[datetime] = None) -> int:
         """Delete all old activations."""
         now = now or datetime.utcnow()
         oldies = self.sas.query(self.Activation).filter(
@@ -103,22 +94,25 @@ class Repository(AbstractRepo, Generic[TActivation, TGroup]):
             self.delete(old)
         return count
 
-    def get_or_create_user_by_email(
-        self, email: str, details: Dict[str, Any]
-    ) -> TUser:
+    def get_or_create_user_by_email(self, email: str, details: Dict[str, Any]) -> TUser:
         """Return User if ``email`` exists, else create User with ``details``.
 
         The returned User instance has a transient ``is_new`` flag.
         If the user is new, they need to go through password recovery.
         # TODO No access to tmp_password, create activation, send email
         """
-        user = self.get_user_by_email(email)
-        if user is None:
+        opt_user = self.get_user_by_email(email)
+        if opt_user is None:
             tmp_password = random_string(length=8)
             user = self.User(email=email, password=tmp_password, **details)
             self.add(user)
             self.flush()
-            user.is_new = tmp_password  # type: ignore
+            user.is_new = tmp_password
         else:  # is_new is a transient variable.
-            user.is_new = False  # type: ignore
+            user = opt_user
+            user.is_new = False
         return user
+
+    def q_users(self) -> Query[TUser]:
+        """Return a query for all users."""
+        return self.sas.query(self.User)
