@@ -9,13 +9,13 @@ from pyramid_mailer.mailer import DummyMailer
 from pyramid.httpexceptions import HTTPNotFound
 
 from pluserable.events import (
-    NewRegistrationEvent,
-    PasswordResetEvent,
+    EventRegistration,
+    EventPasswordReset,
     EventProfileUpdated,
 )
 from pluserable.interfaces import ILoginForm, ILoginSchema
 from pluserable.strings import UIStringsBase
-from pluserable.views import (
+from pluserable.web.pyramid.views import (
     AuthView,
     ForgotPasswordView,
     ProfileView,
@@ -23,7 +23,7 @@ from pluserable.views import (
 )
 
 from tests.models import User
-from tests.integration import IntegrationTestBase
+from tests.integration import IntegrationTestBase, LoggedIntegrationTest
 
 
 class TestAuthView(IntegrationTestBase):  # noqa
@@ -43,34 +43,17 @@ class TestAuthView(IntegrationTestBase):  # noqa
         assert form.called
 
     def test_login_loads(self):  # noqa
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
         self.config.add_route("index", "/")
 
         request = self.get_request()
-        request.user = None
         view = AuthView(request)
         response = view.login()
 
         assert response.get("form", None)
 
-    def test_login_redirects_if_logged_in(self):  # noqa
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
-        self.config.add_route("index", "/")
-
-        request = self.get_request()
-        request.user = Mock()
-        view = AuthView(request)
-
-        response = view.login()
-        assert response.status_int == 302
-
     def test_login_fails_empty(self):
         """Make sure we can't log in with empty credentials."""
         self.config.add_route("index", "/")
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
 
         request = self.get_request(
             post={
@@ -92,8 +75,6 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
     def test_login_fails_bad_credentials(self):
         """Make sure we can't log in with bad credentials."""
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
         self.config.add_route("index", "/")
 
         request = self.get_request(
@@ -115,10 +96,8 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
     def test_login_succeeds(self):
         """Make sure we can log in."""
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
         self.config.add_route("index", "/")
-        user = self.create_users(count=1)
+        user = self.create_users(count=1, password="science")
         self.sas.flush()
 
         request = self.get_request(
@@ -140,11 +119,9 @@ class TestAuthView(IntegrationTestBase):  # noqa
 
     def test_inactive_login_fails(self):
         """Ensure we can't log in with an inactive user."""
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
         self.config.add_route("index", "/")
 
-        user = self.create_users(count=1, activation=True)
+        user = self.create_users(count=1, password="science", activation=True)
         self.sas.flush()
 
         request = self.get_request(
@@ -165,31 +142,6 @@ class TestAuthView(IntegrationTestBase):  # noqa
             level="danger",
         )
 
-    def test_logout(self):
-        """User logs out successfully."""
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
-        self.config.add_route("index", "/")
-        request = self.get_request()
-
-        invalidate = Mock()
-        request.add_flash = Mock()
-        request.user = Mock()
-        request.session = Mock()
-        request.session.invalidate = invalidate
-
-        view = AuthView(request)
-        with patch("pluserable.views.forget") as forget:
-            with patch("pluserable.views.HTTPFound") as HTTPFound:
-                view.logout()
-                request.add_flash.assert_called_with(
-                    plain=UIStringsBase.logout_done, level="success"
-                )
-
-                forget.assert_called_with(request)
-                assert invalidate.called
-                assert HTTPFound.called
-
 
 class TestRegisterView(IntegrationTestBase):  # noqa
     def test_register_loads_not_logged_in(self):  # noqa
@@ -197,25 +149,11 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         self.config.add_route("index", "/")
 
         request = self.get_request()
-        request.user = None
         view = RegisterView(request)
         response = view.register()
 
         assert response.get("form", None)
 
-    def test_register_redirects_if_logged_in(self):  # noqa
-        self.config.registry.settings["pluserable.login_redirect"] = "index"
-        self.config.registry.settings["pluserable.logout_redirect"] = "index"
-        self.config.registry.registerUtility(DummyMailer(), IMailer)
-        self.config.add_route("index", "/")
-
-        request = self.get_request()
-        request.user = Mock()
-        view = RegisterView(request)
-        response = view.register()
-
-        assert response.status_int == 302
-
     def test_register_creates_inactive_user(self):  # noqa
         self.config.registry.registerUtility(DummyMailer(), IMailer)
         self.config.add_route("index", "/")
@@ -233,7 +171,6 @@ class TestRegisterView(IntegrationTestBase):  # noqa
             request_method="POST",
         )
         request.add_flash = Mock()
-        request.user = Mock()
         view = RegisterView(request)
         response = view.register()
 
@@ -247,7 +184,6 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         self.config.add_route("index", "/")
 
         request = self.get_request(request_method="POST")
-        request.user = Mock()
         view = RegisterView(request)
         response = view.register()
 
@@ -277,17 +213,10 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         assert isinstance(adict, dict)
         assert adict["errors"]
 
-    @patch("pluserable.views.require_activation_setting_value")
-    def test_register_no_activation_suceeds(self, get_setting_mock):
+    def test_register_no_activation_suceeds(self):
         """Test register() with setting to not require activation."""
-        get_setting_mock.return_value = False
         self.config.add_route("index", "/")
 
-        def handle_registration(event):
-            event.request.repo.flush()
-
-        self.config.add_subscriber(handle_registration, NewRegistrationEvent)
-
         request = self.get_request(
             post={
                 "username": "admin",
@@ -300,9 +229,9 @@ class TestRegisterView(IntegrationTestBase):  # noqa
             },
             request_method="POST",
         )
+        request.kerno.pluserable_settings["require_activation"] = False
 
         request.add_flash = Mock()
-        request.user = Mock()
 
         view = RegisterView(request)
         response = view.register()
@@ -313,7 +242,7 @@ class TestRegisterView(IntegrationTestBase):  # noqa
         user = request.repo.get_user_by_username("admin")
         assert user.is_activated is True
 
-    def test_registration_craps_out(self):  # noqa
+    def test_registration_fails_with_mailer(self):  # noqa
         self.config.add_route("index", "/")
 
         def send(message):
@@ -444,33 +373,36 @@ class TestRegisterView(IntegrationTestBase):  # noqa
 
 
 class TestForgotPasswordView(IntegrationTestBase):  # noqa
+    def test_forgot_password_invalid_password(self):  # noqa
+        self.config.add_route("index", "/")
+        self.config.registry.registerUtility(DummyMailer(), IMailer)
+        self.create_users(count=1)
+        self.sas.flush()
+        request = self.get_request(
+            post={
+                "email": "sagan",
+                "csrf_token": "irrelevant but required",
+            },
+            request_method="POST",
+        )
+        view = ForgotPasswordView(request)
+
+        response = view.forgot_password()
+        assert len(response["errors"]) == 1
+
     def test_forgot_password_loads(self):  # noqa
         self.config.add_route("index", "/")
-
         request = self.get_request()
-        request.user = None
         view = ForgotPasswordView(request)
-        response = view.forgot_password()
 
+        response = view.forgot_password()
         assert response.get("form", None)
 
-    def test_forgot_password_logged_in_redirects(self):  # noqa
-        self.config.add_route("index", "/")
-
-        request = self.get_request()
-        request.user = Mock()
-        view = ForgotPasswordView(request)
-        response = view.forgot_password()
-
-        assert response.status_int == 302
-
     def test_forgot_password_valid_user_succeeds(self):  # noqa
         self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
-
         self.create_users(count=1)
         self.sas.flush()
-
         request = self.get_request(
             post={
                 "email": "carlsagan1@nasa.gov",
@@ -479,36 +411,72 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
             request_method="POST",
         )
         request.add_flash = Mock()
-        request.user = None
-
         view = ForgotPasswordView(request)
-        response = view.forgot_password()
 
+        response = view.forgot_password()
         request.add_flash.assert_called_with(
             plain=UIStringsBase.reset_password_email_sent, level="success"
         )
         assert response.status_int == 302
 
-    def test_forgot_password_invalid_password(self):  # noqa
+    def test_invalid_reset_gets_404(self):  # noqa
+        self.config.registry.registerUtility(DummyMailer(), IMailer)
+        self.config.add_route("index", "/")
+
+        self.create_users(count=1, activation=True)
+        self.sas.flush()
+
+        request = self.get_request()
+        request.matchdict = Mock()
+        get = Mock()
+        get.return_value = "wrong value"
+        request.matchdict.get = get
+        view = ForgotPasswordView(request)
+
+        with self.assertRaises(HTTPNotFound):
+            view.reset_password()
+
+    def test_reset_password_empty_password(self):  # noqa
+        self.config.registry.registerUtility(DummyMailer(), IMailer)
+        self.config.add_route("index", "/")
+
+        user = self.create_users(count=1, activation=True)
+        self.sas.flush()
+
+        request = self.get_request(request_method="POST")
+        request.matchdict = Mock()
+        get = Mock()
+        get.return_value = user.activation.code
+        request.matchdict.get = get
+        view = ForgotPasswordView(request)
+
+        response = view.reset_password()
+        assert len(response["errors"]) == 1
+
+    def test_reset_password_invalid_password(self):  # noqa
         self.config.add_route("index", "/")
         self.config.registry.registerUtility(DummyMailer(), IMailer)
 
-        self.create_users(count=1)
+        user = self.create_users(count=1, activation=True)
         self.sas.flush()
 
         request = self.get_request(
             post={
-                "email": "sagan",
+                "Password": {
+                    "Password": "t",
+                    "Password-confirm": "t",
+                },
                 "csrf_token": "irrelevant but required",
             },
             request_method="POST",
         )
-
-        request.user = None
-
+        request.matchdict = Mock()
+        get = Mock()
+        get.return_value = user.activation.code
+        request.matchdict.get = get
         view = ForgotPasswordView(request)
-        response = view.forgot_password()
 
+        response = view.reset_password()
         assert len(response["errors"]) == 1
 
     def test_reset_password_loads(self):  # noqa
@@ -519,17 +487,13 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         self.sas.flush()
 
         request = self.get_request()
-
         request.matchdict = Mock()
         get = Mock()
         get.return_value = user.activation.code
         request.matchdict.get = get
-
-        request.user = None
-
         view = ForgotPasswordView(request)
-        response = view.reset_password()
 
+        response = view.reset_password()
         assert response.get("form", None)
         assert "sagan" in response["form"]
 
@@ -555,118 +519,58 @@ class TestForgotPasswordView(IntegrationTestBase):  # noqa
         get = Mock()
         get.return_value = user.activation.code
         request.matchdict.get = get
-
-        request.user = None
-
-        def handle_password_reset(event):
-            event.request.repo.flush()
-
-        self.config.add_subscriber(handle_password_reset, PasswordResetEvent)
-
         view = ForgotPasswordView(request)
-        response = view.reset_password()
 
+        response = view.reset_password()
         assert user.check_password("test123")
         assert response.status_int == 302
 
-    def test_reset_password_invalid_password(self):  # noqa
+
+class TestLoggedIn(LoggedIntegrationTest):  # noqa
+    def test_forgot_password_logged_in_redirects(self):  # noqa
         self.config.add_route("index", "/")
-        self.config.registry.registerUtility(DummyMailer(), IMailer)
-
-        user = self.create_users(count=1, activation=True)
-        self.sas.flush()
-
-        request = self.get_request(
-            post={
-                "Password": {
-                    "Password": "t",
-                    "Password-confirm": "t",
-                },
-                "csrf_token": "irrelevant but required",
-            },
-            request_method="POST",
-        )
-
-        request.matchdict = Mock()
-        get = Mock()
-        get.return_value = user.activation.code
-        request.matchdict.get = get
-
-        request.user = None
-
+        request = self.get_request()
         view = ForgotPasswordView(request)
-        response = view.reset_password()
 
-        assert len(response["errors"]) == 1
+        response = view.forgot_password()
+        assert response.status_int == 302
 
-    def test_reset_password_empty_password(self):  # noqa
-        self.config.registry.registerUtility(DummyMailer(), IMailer)
+    def test_login_redirects_if_logged_in(self):  # noqa
         self.config.add_route("index", "/")
+        request = self.get_request()
+        view = AuthView(request)
 
-        user = self.create_users(count=1, activation=True)
-        self.sas.flush()
+        response = view.login()
+        assert response.status_int == 302
+        assert response.headers["Location"] == "/"
 
-        request = self.get_request(request_method="POST")
-        request.matchdict = Mock()
-        get = Mock()
-        get.return_value = user.activation.code
-        request.matchdict.get = get
-        request.user = None
-
-        view = ForgotPasswordView(request)
-        response = view.reset_password()
-
-        assert len(response["errors"]) == 1
-
-    def test_invalid_reset_gets_404(self):  # noqa
-        self.config.registry.registerUtility(DummyMailer(), IMailer)
+    def test_logout(self):
+        """User logs out successfully."""
         self.config.add_route("index", "/")
+        request = self.get_request()
 
-        self.create_users(count=1, activation=True)
-        self.sas.flush()
+        invalidate = Mock()
+        request.add_flash = Mock()
+        request.session = Mock()
+        request.session.invalidate = invalidate
+
+        view = AuthView(request)
+        with patch("pluserable.web.pyramid.views.forget") as forget:
+            with patch("pluserable.web.pyramid.views.HTTPFound") as HTTPFound:
+                view.logout()
+                request.add_flash.assert_called_with(
+                    plain=UIStringsBase.logout_done, level="success"
+                )
+
+                forget.assert_called_with(request)
+                assert invalidate.called
+                assert HTTPFound.called
+
+    def test_profile_view_bad_id(self):  # noqa
+        self.config.add_route("index", "/")
 
         request = self.get_request()
         request.matchdict = Mock()
-        get = Mock()
-        get.return_value = "wrong value"
-        request.matchdict.get = get
-
-        request.user = None  # nobody is logged in
-        view = ForgotPasswordView(request)
-        with self.assertRaises(HTTPNotFound):
-            view.reset_password()
-
-
-class TestProfileView(IntegrationTestBase):  # noqa
-    def test_profile_loads(self):  # noqa
-        self.config.add_route("index", "/")
-
-        user = self.create_users(count=1)
-        self.sas.flush()
-
-        request = self.get_request()
-        request.user = Mock()
-
-        request.matchdict = Mock()
-        get = Mock()
-        get.return_value = user.id
-        request.matchdict.get = get
-
-        view = ProfileView(request)
-
-        response = view.profile()
-
-        assert response.get("user", None) == user
-
-    def test_profile_bad_id(self):  # noqa
-        self.config.add_route("index", "/")
-
-        self.create_users(count=1)
-        self.sas.flush()
-
-        request = self.get_request()
-        request.user = Mock()
-        request.matchdict = Mock()
 
         get = Mock()
         get.return_value = 99  # This user ID does not exist
@@ -676,35 +580,23 @@ class TestProfileView(IntegrationTestBase):  # noqa
         with self.assertRaises(HTTPNotFound):
             view.profile()
 
-    def test_profile_update_profile_invalid(self):  # noqa
-        from pluserable.interfaces import IProfileSchema
-        from tests.schemas import ProfileSchema
-
-        self.config.registry.registerUtility(ProfileSchema, IProfileSchema)
+    def test_profile_view_loads(self):  # noqa
         self.config.add_route("index", "/")
-
-        user = self.create_users(count=1)
-        self.sas.flush()
-
-        request = self.get_request(request_method="POST")
-        request.user = user
-
+        request = self.get_request()
         request.matchdict = Mock()
         get = Mock()
-        get.return_value = user.id
+        get.return_value = request.identity.id
         request.matchdict.get = get
 
-        # The code being tested
-        response = ProfileView(request).edit_profile()
+        view = ProfileView(request)
 
-        assert len(response["errors"]) == 3
+        response = view.profile()
+
+        assert response.get("user", None) == request.identity
 
     def test_profile_update_email(self):  # noqa
         self.config.add_route("index", "/")
 
-        user = self.create_users(count=1)
-        self.sas.flush()
-
         def handle_profile_updated(event):
             event.request.repo.flush()
 
@@ -719,30 +611,27 @@ class TestProfileView(IntegrationTestBase):  # noqa
             },
             request_method="POST",
         )
+        assert request.identity
         request.add_flash = Mock()
-        request.user = user
         request.matchdict = Mock()
         get = Mock()
-        get.return_value = user.id
+        get.return_value = request.identity.id
         request.matchdict.get = get
 
         # The code being tested
         ProfileView(request).edit_profile()
 
         # Assertions
-        the_user = request.repo.get_user_by_id(user.id)
-        assert the_user is user
+        the_user = request.repo.get_user_by_id(request.identity.id)
+        assert the_user is request.identity
         assert the_user.email == "new_email@nasa.gov"
-        assert user.check_password("science")
+        assert the_user.password == "Please bypass hashing!"
 
     def test_profile_update_password(self):  # noqa  # Happy
         self.config.add_route("index", "/")
-        user = self.create_users(count=1)
-        self.sas.flush()
-
         request = self.get_request(
             post={
-                "email": user.email,
+                "email": self.user.email,
                 "password": {
                     "password": "new password",
                     "password-confirm": "new password",
@@ -752,11 +641,10 @@ class TestProfileView(IntegrationTestBase):  # noqa
             request_method="POST",
         )
         request.add_flash = Mock()
-        request.user = user
 
         request.matchdict = Mock()
         get = Mock()
-        get.return_value = user.id
+        get.return_value = self.user.id
         request.matchdict.get = get
 
         handle_profile_updated = Mock()
@@ -768,7 +656,34 @@ class TestProfileView(IntegrationTestBase):  # noqa
         ProfileView(request).edit_profile()
 
         # Assertions
-        assert user in request.repo.sas.dirty
-        assert user.email == "carlsagan1@nasa.gov"
-        assert user.check_password("new password")
+        assert self.user in request.repo.sas.dirty
+        assert self.user.email == "carlsagan1@nasa.gov"
+        assert self.user.check_password("new password")
         assert handle_profile_updated.called
+
+    def test_register_redirects_if_logged_in(self):  # noqa
+        self.config.registry.registerUtility(DummyMailer(), IMailer)
+        self.config.add_route("index", "/")
+        request = self.get_request()
+        view = RegisterView(request)
+
+        response = view.register()
+        assert response.status_int == 302
+
+    def test_update_profile_invalid(self):  # noqa
+        from pluserable.interfaces import IProfileSchema
+        from tests.schemas import ProfileSchema
+
+        self.config.registry.registerUtility(ProfileSchema, IProfileSchema)
+        self.config.add_route("index", "/")
+        request = self.get_request(request_method="POST")
+
+        request.matchdict = Mock()
+        get = Mock()
+        get.return_value = request.identity.id
+        request.matchdict.get = get
+
+        # The code being tested
+        response = ProfileView(request).edit_profile()
+
+        assert len(response["errors"]) == 3
